pygeoid
=======

.. image:: https://img.shields.io/pypi/v/pygeoid.svg
    :target: https://pypi.org/project/pygeoid/

.. image:: https://travis-ci.org/ioshchepkov/pygeoid.svg
    :target: https://travis-ci.org/ioshchepkov/pygeoid

.. image:: https://coveralls.io/repos/github/ioshchepkov/pygeoid/badge.svg
    :target: https://coveralls.io/github/ioshchepkov/pygeoid

.. image:: https://readthedocs.org/projects/pygeoid/badge/?version=latest
    :target: http://pygeoid.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/gitter/room/opengrav/pygeoid.svg 
    :target: https://gitter.im/opengrav/pygeoid
    :alt: Chat room on Gitter

Local gravity field modelling with Python.

The main purpose of the package is to realise common algorithms and
methods in physical geodesy for the local gravity field modelling.

The project is in the early planning and development stage.

Install
-------

To install ``pygeoid`` simply use ``pip`` as usual: 

.. code:: bash

    pip install pygeoid

Alternatively, you can use ``pip`` to install the latest version of the source code from GitHub:

.. code:: bash

    pip install --upgrade git+https://github.com/ioshchepkov/pygeoid

Documentation
-------------

Full documentation is available at https://pygeoid.readthedocs.io

Code of Conduct
---------------

Please note that *PyGeoid* is released with a Code of Conduct
(see `CODE_OF_CONDUCT.md <https://github.com/ioshchepkov/pygeoid/blob/master/CODE_OF_CONDUCT.md>`__).
By participating in this project you agree that you will follow all its terms.

License
-------

This project is licensed under the MIT License - see the LICENSE.txt file for details

